==> gcompris-qt_1.1.orig.tar.xz: gcompris-qt-1.1/src/activities/money/moneyConstants.js <==
/* GCompris - moneyConstants.js
 *
 * Copyright (C) 2019 Akshay Kumar <email.akshay98@gmail.com>
 *
 * Authors:
 *   Akshay Kumar <email.akshay98@gmail.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

var cheapObjects = [
    "qrc:/gcompris/src/activities/babymatch/resource/images/apple.svg",
    "qrc:/gcompris/src/activities/babyshapes/resource/food/orange.svg",
    "qrc:/gcompris/src/activities/babyshapes/resource/food/banana.svg",
    "qrc:/gcompris/src/activities/babyshapes/resource/food/grapefruit.svg",
    "qrc:/gcompris/src/activities/babymatch/resource/images/carrot.svg",
    "qrc:/gcompris/src/activities/babymatch/resource/images/flower.svg",
    "qrc:/gcompris/src/activities/babyshapes/resource/food/chocolate_cake.svg"
]

var normalObjects = [
    "qrc:/gcompris/src/activities/babymatch/resource/images/flowerpot.svg",
    "qrc:/gcompris/src/activities/babymatch/resource/images/pencil.svg",
    "qrc:/gcompris/src/activities/babymatch/resource/images/bottle.svg",
    "qrc:/gcompris/src/activities/babymatch/resource/images/light.svg",
    "qrc:/gcompris/src/activities/babymatch/resource/images/eggpot.svg"
]

var expensiveObjects = [
    "qrc:/gcompris/src/activities/babymatch/resource/images/lamp.svg",
    "qrc:/gcompris/src/activities/babymatch/resource/images/football.svg",
    "qrc:/gcompris/src/activities/babymatch/resource/images/bicycle.svg"
]

var moneyItems = {
    MONEY_COIN_1C:   { img: "qrc:/gcompris/src/activities/money/resource/c1c.svg",  val: 0.01 },
    MONEY_COIN_2C:   { img: "qrc:/gcompris/src/activities/money/resource/c2c.svg",  val: 0.02 },
    MONEY_COIN_5C:   { img: "qrc:/gcompris/src/activities/money/resource/c5c.svg",  val: 0.05 },
    MONEY_COIN_10C:  { img: "qrc:/gcompris/src/activities/money/resource/c10c.svg", val: 0.1  },
    MONEY_COIN_20C:  { img: "qrc:/gcompris/src/activities/money/resource/c20c.svg", val: 0.20 },
    MONEY_COIN_50C:  { img: "qrc:/gcompris/src/activities/money/resource/c50c.svg", val: 0.5  },
    MONEY_COIN_1E:   { img: "qrc:/gcompris/src/activities/money/resource/c1e.svg",  val: 1.0  },
    MONEY_COIN_2E:   { img: "qrc:/gcompris/src/activities/money/resource/c2e.svg",  val: 2.0  },
    MONEY_PAPER_5E:  { img: "qrc:/gcompris/src/activities/money/resource/n5e.svg",  val: 5.0  },
    MONEY_PAPER_10E: { img: "qrc:/gcompris/src/activities/money/resource/n10e.svg", val: 10.0 },
    MONEY_PAPER_20E: { img: "qrc:/gcompris/src/activities/money/resource/n20e.svg", val: 20.0 },
    MONEY_PAPER_50E: { img: "qrc:/gcompris/src/activities/money/resource/n50e.svg", val: 50.0 },
    MONEY_PAPER_100E: { img: "qrc:/gcompris/src/activities/money/resource/n100e.png", val: 100.0 },
    MONEY_PAPER_200E: { img: "qrc:/gcompris/src/activities/money/resource/n200e.svg", val: 200.0 },
    MONEY_PAPER_500E: { img: "qrc:/gcompris/src/activities/money/resource/n500e.png", val: 500.0 }
}

==> gcompris-qt-25.1.1.tar.xz: gcompris-qt-25.1.1/src/activities/money/moneyConstants.js <==
/* GCompris - moneyConstants.js
 *
 * SPDX-FileCopyrightText: 2019 Akshay Kumar <email.akshay98@gmail.com>
 *
 * Authors:
 *   Akshay Kumar <email.akshay98@gmail.com>
 *
 *   SPDX-License-Identifier: GPL-3.0-or-later
 */

var cheapObjects = [
    "qrc:/gcompris/src/activities/babymatch/resource/images/apple.svg",
    "qrc:/gcompris/src/activities/babyshapes/resource/food/orange.svg",
    "qrc:/gcompris/src/activities/babyshapes/resource/food/banana.svg",
    "qrc:/gcompris/src/activities/babyshapes/resource/food/grapefruit.svg",
    "qrc:/gcompris/src/activities/babymatch/resource/images/carrot.svg",
    "qrc:/gcompris/src/activities/babymatch/resource/images/flower.svg",
    "qrc:/gcompris/src/activities/babyshapes/resource/food/chocolate_cake.svg"
]

var normalObjects = [
    "qrc:/gcompris/src/activities/babymatch/resource/images/flowerpot.svg",
    "qrc:/gcompris/src/activities/babymatch/resource/images/pencil.svg",
    "qrc:/gcompris/src/activities/babymatch/resource/images/bottle.svg",
    "qrc:/gcompris/src/activities/babymatch/resource/images/light.svg",
    "qrc:/gcompris/src/activities/babymatch/resource/images/eggpot.svg"
]

var expensiveObjects = [
    "qrc:/gcompris/src/activities/babymatch/resource/images/lamp.svg",
    "qrc:/gcompris/src/activities/babymatch/resource/images/minivan.svg",
    "qrc:/gcompris/src/activities/babymatch/resource/images/bicycle.svg"
]

var moneyItems = {
    MONEY_COIN_1C:   { img: "qrc:/gcompris/src/activities/money/resource/c1c.svg",  val: 0.01 },
    MONEY_COIN_2C:   { img: "qrc:/gcompris/src/activities/money/resource/c2c.svg",  val: 0.02 },
    MONEY_COIN_5C:   { img: "qrc:/gcompris/src/activities/money/resource/c5c.svg",  val: 0.05 },
    MONEY_COIN_10C:  { img: "qrc:/gcompris/src/activities/money/resource/c10c.svg", val: 0.1  },
    MONEY_COIN_20C:  { img: "qrc:/gcompris/src/activities/money/resource/c20c.svg", val: 0.20 },
    MONEY_COIN_50C:  { img: "qrc:/gcompris/src/activities/money/resource/c50c.svg", val: 0.5  },
    MONEY_COIN_1E:   { img: "qrc:/gcompris/src/activities/money/resource/c1e.svg",  val: 1.0  },
    MONEY_COIN_2E:   { img: "qrc:/gcompris/src/activities/money/resource/c2e.svg",  val: 2.0  },
    MONEY_PAPER_5E:  { img: "qrc:/gcompris/src/activities/money/resource/n5e.svg",  val: 5.0  },
    MONEY_PAPER_10E: { img: "qrc:/gcompris/src/activities/money/resource/n10e.svg", val: 10.0 },
    MONEY_PAPER_20E: { img: "qrc:/gcompris/src/activities/money/resource/n20e.svg", val: 20.0 },
    MONEY_PAPER_50E: { img: "qrc:/gcompris/src/activities/money/resource/n50e.svg", val: 50.0 },
    MONEY_PAPER_100E: { img: "qrc:/gcompris/src/activities/money/resource/n100e.svg", val: 100.0 },
    MONEY_PAPER_200E: { img: "qrc:/gcompris/src/activities/money/resource/n200e.svg", val: 200.0 },
    MONEY_PAPER_500E: { img: "qrc:/gcompris/src/activities/money/resource/n500e.svg", val: 500.0 }
}
